Method: BitBucket::Connection.stack
- Defined in:
- lib/bitbucket_rest_api/connection.rb
.stack(options = {}, &block) ⇒ Object
Exposes middleware builder to facilitate custom stacks and easy addition of new extensions such as cache adapter.
75 76 77 78 79 80 81 82 83 |
# File 'lib/bitbucket_rest_api/connection.rb', line 75 def stack( = {}, &block) @stack ||= begin if block_given? Faraday::RackBuilder.new(&block) else Faraday::RackBuilder.new(&default_middleware()) end end end |